@@ -410,6 +410,10 @@
         <source>Update</source>
         <translation>Actualitza</translation>
     </message>
+    <message>
+        <source>Please plug in and then install updates.</source>
+        <translation>Si us plau, endolleu l&apos;ordinador i després instal·leu les actualitzacions.</translation>
+    </message>
 </context>
 <context>
     <name>update</name>
