@@ -410,6 +410,10 @@
         <source>Update</source>
         <translation>Aktualisieren</translation>
     </message>
+    <message>
+        <source>Please plug in and then install updates.</source>
+        <translation>Bitte ans Stromnetz anschließen und dann Aktualisierungen installieren</translation>
+    </message>
 </context>
 <context>
     <name>update</name>
