@@ -410,6 +410,10 @@
         <source>Update</source>
         <translation>Päivitä</translation>
     </message>
+    <message>
+        <source>Please plug in and then install updates.</source>
+        <translation>Kytke sähköverkkoon ja asenna sitten päivitykset.</translation>
+    </message>
 </context>
 <context>
     <name>update</name>
