@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="ja">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ja">
 <context>
     <name>CheckUpdate</name>
     <message>
@@ -27,7 +25,7 @@
     <name>UpdateControl</name>
     <message>
         <source>View Update Log</source>
-        <translation type="unfinished"></translation>
+        <translation>アップデートログを表示</translation>
     </message>
 </context>
 <context>
@@ -38,7 +36,7 @@
     </message>
     <message>
         <source>No update history</source>
-        <translation>アップデート履歴はありません</translation>
+        <translation>アップデートの履歴はありません</translation>
     </message>
     <message>
         <source>System Updates</source>
@@ -50,11 +48,11 @@
     </message>
     <message>
         <source>Delivers a cumulative update including new features, quality updates, and security updates</source>
-        <translation>新しい機能、品質改善、セキュリティのアップデートが配信されます</translation>
+        <translation>新しい機能、品質改善、セキュリティのアップデートが含まれます</translation>
     </message>
     <message>
         <source>Delivers security updates</source>
-        <translation>セキュリティのアップデートが配信されます</translation>
+        <translation>セキュリティのアップデートが含まれます</translation>
     </message>
     <message>
         <source>Installation date:</source>
@@ -77,22 +75,22 @@
     </message>
     <message>
         <source>Version:</source>
-        <translation type="unfinished"></translation>
+        <translation>バージョン:</translation>
     </message>
 </context>
 <context>
     <name>UpdateLogDialog</name>
     <message>
         <source>Update Log</source>
-        <translation type="unfinished"></translation>
+        <translation>アップデートログ</translation>
     </message>
     <message>
         <source>Close</source>
-        <translation type="unfinished"></translation>
+        <translation>閉じる</translation>
     </message>
     <message>
         <source>Export to desktop</source>
-        <translation type="unfinished"></translation>
+        <translation>デスクトップにエクスポート</translation>
     </message>
 </context>
 <context>
@@ -225,7 +223,7 @@
     </message>
     <message>
         <source>Check Again</source>
-        <translation>再確認</translation>
+        <translation>もう一度確認する</translation>
     </message>
     <message>
         <source>Privacy Policy</source>
@@ -249,7 +247,7 @@
     </message>
     <message>
         <source>The system has enabled auto recovery function and does not support updates. If you have any questions, please contact the enterprise administrator</source>
-        <translation type="unfinished"></translation>
+        <translation>自動リカバリ機能が有効になっているため、アップデートを利用できません。詳細はシステム管理者にお問い合わせください</translation>
     </message>
 </context>
 <context>
@@ -347,7 +345,7 @@
     </message>
     <message>
         <source>Update History</source>
-        <translation>アップデート履歴</translation>
+        <translation>アップデートログ</translation>
     </message>
     <message>
         <source>View</source>
@@ -398,20 +396,24 @@
     </message>
     <message>
         <source>updatelog</source>
-        <translation type="unfinished"></translation>
+        <translation>アップデートログ</translation>
     </message>
     <message>
         <source>Log export failed, please try again</source>
-        <translation type="unfinished"></translation>
+        <translation>ログをエクスポートできませんでした。もう一度お試しください</translation>
     </message>
     <message>
         <source>The log has been exported to the desktop</source>
-        <translation type="unfinished"></translation>
+        <translation>ログがデスクトップにエクスポートされました</translation>
     </message>
     <message>
         <source>Update</source>
         <translation>アップデート</translation>
     </message>
+    <message>
+        <source>Please plug in and then install updates.</source>
+        <translation>アップデートをインストールするには、電源に接続してください。</translation>
+    </message>
 </context>
 <context>
     <name>update</name>
@@ -527,4 +529,4 @@
         <translation>バッテリー残量が60%以下です。正常にアップデートを実行するため、電源に接続してください。</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
