@@ -410,6 +410,10 @@
         <source>Update</source>
         <translation>Bijwerken</translation>
     </message>
+    <message>
+        <source>Please plug in and then install updates.</source>
+        <translation>Sluit de netstroomadapter aan alvorens de updates te installeren.</translation>
+    </message>
 </context>
 <context>
     <name>update</name>
