@@ -231,7 +231,7 @@
     </message>
     <message>
         <source>To use this software, you must accept the %1 that accompanies software updates.</source>
-        <translation>Aby korzystać z tego oprogramowania, musisz zaakceptować %1, dołączoną do aktualizacji.</translation>
+        <translation>Aby korzystać z tego oprogramowania, musisz zaakceptować %1 dołączoną do aktualizacji.</translation>
     </message>
     <message>
         <source>Turn on the switches under Update Content to get better experiences</source>
@@ -410,6 +410,10 @@
         <source>Update</source>
         <translation>Aktualizuj</translation>
     </message>
+    <message>
+        <source>Please plug in and then install updates.</source>
+        <translation>Najpierw podłącz się do zasilania, aby zainstalować aktualizacje.</translation>
+    </message>
 </context>
 <context>
     <name>update</name>
