@@ -410,6 +410,10 @@
         <source>Update</source>
         <translation>Përditësim</translation>
     </message>
+    <message>
+        <source>Please plug in and then install updates.</source>
+        <translation>Ju lutemi, vëreni në prizë dhe mandej instaloni përditësimet.</translation>
+    </message>
 </context>
 <context>
     <name>update</name>
