@@ -410,6 +410,10 @@
         <source>Update</source>
         <translation>Оновлення</translation>
     </message>
+    <message>
+        <source>Please plug in and then install updates.</source>
+        <translation>Будь ласка, з&apos;єднайте комп&apos;ютер з джерелом живлення, потім встановлюйте оновлення.</translation>
+    </message>
 </context>
 <context>
     <name>update</name>
