@@ -410,6 +410,10 @@
         <source>Update</source>
         <translation>更新</translation>
     </message>
+    <message>
+        <source>Please plug in and then install updates.</source>
+        <translation>請插入電源後再開始更新</translation>
+    </message>
 </context>
 <context>
     <name>update</name>
