@@ -4,8 +4,9 @@
 
 #include "updateworker.h"
 #include "dconfig_helper.h"
-#include "common/dbus/updatejobdbusproxy.h"
 #include "common/commondefine.h"
+#include "common/dbus/updatejobdbusproxy.h"
+#include "common/global_util/public_func.h"
 
 #include <QTimer>
 #include <QDir>
@@ -20,9 +21,14 @@
 #include <QWidget>
 #include <QApplication>
 #include <QFile>
+#include <QFileSystemWatcher>
+#include <QTextStream>
+#include <QStandardPaths>
 
 #include <DDBusSender>
 
+Q_LOGGING_CATEGORY(DDE_UPDATE_WORKER, "dde-update-worker")
+
 static const QList<UpdateModel::UpdateError> CAN_BE_FIXED_ERRORS = { UpdateModel::DpkgInterrupted };
 
 UpdateWorker::UpdateWorker(QObject *parent)
@@ -32,6 +38,7 @@ UpdateWorker::UpdateWorker(QObject *parent)
     , m_checkSystemJob(nullptr)
     , m_dbusProxy(new UpdateDBusProxy(this))
     , m_waitingToCheckSystem(false)
+    , m_logWatcherHelper(new LogWatcherHelper(this))
 {
 }
 
@@ -61,48 +68,21 @@ void UpdateWorker::init()
             }
         }
     });
-#if 0 // TODO
-    connect(m_abRecoveryInter, &RecoveryInter::JobEnd, this, [](const QString &kind, bool success, const QString &errMsg) {
-        qInfo() << "Backup job end, kind: " << kind << ", success: " << success << ", error message: " << errMsg;
-        if ("backup" != kind) {
-            qWarning() << "Kind error: " << kind;
-            return;
-        }
-
-        if (success) {
-            UpdateModel::instance()->setUpdateStatus(UpdateModel::UpdateStatus::BackupSuccess);
-        } else {
-            UpdateModel::instance()->setLastErrorLog(errMsg);
-            UpdateModel::instance()->setUpdateError(UpdateModel::UpdateError::BackupFailedUnknownReason);
-            UpdateModel::instance()->setUpdateStatus(UpdateModel::UpdateStatus::BackupFailed);
-        }
-    });
-    connect(m_abRecoveryInter, &RecoveryInter::BackingUpChanged, this, [](bool value) {
-        qInfo() << "Backing up changed: " << value;
-        if (value) {
-            UpdateModel::instance()->setUpdateStatus(UpdateModel::UpdateStatus::BackingUp);
-        }
-    });
-    connect(m_abRecoveryInter, &RecoveryInter::ConfigValidChanged, this, [](bool value) {
-        qInfo() << "Backup config valid changed: " << value;
-        UpdateModel::instance()->setBackupConfigValidation(value);
-    });
-    connect(m_abRecoveryInter, &RecoveryInter::serviceValidChanged, this, [](bool valid) {
-        if (!valid) {
-            const auto status = UpdateModel::instance()->updateStatus();
-            qWarning() << "AB recovery service was invalid, current status: " << status;
-            if (status != UpdateModel::BackingUp)
-                return;
-
-            UpdateModel::instance()->setLastErrorLog("AB recovery service was invalid.");
-            UpdateModel::instance()->setUpdateError(UpdateModel::UpdateError::BackupInterfaceError);
-            UpdateModel::instance()->setUpdateStatus(UpdateModel::UpdateStatus::BackupFailed);
-        }
-    });
-#endif
 
     getUpdateOption();
     onJobListChanged(m_dbusProxy->jobList());
+
+    connect(m_logWatcherHelper, &LogWatcherHelper::incrementalDataChanged, this, [](const QString &data) {
+        UpdateModel::instance()->appendUpdateLog(data);
+    });
+
+    connect(m_logWatcherHelper, &LogWatcherHelper::fileReset, this, []() {
+        UpdateModel::instance()->setUpdateLog(QString());
+    });
+
+    QTimer::singleShot(0, this, [this]() {
+        m_logWatcherHelper->startWatchFile();
+    });
 }
 
 /**
@@ -120,7 +100,7 @@ void UpdateWorker::doDistUpgrade(bool doBackup)
 {
     qInfo() << "Do dist upgrade, do backup: " << doBackup;
     if (!m_dbusProxy->managerInterIsValid()) {
-        UpdateModel::instance()->setLastErrorLog("com.deepin.lastore.Manager interface is invalid.");
+        UpdateModel::instance()->setLastErrorLog("org.deepin.dde.Lastore1.Manager interface is invalid.");
         UpdateModel::instance()->setUpdateError(UpdateModel::UpdateError::UpdateInterfaceError);
         UpdateModel::instance()->setUpdateStatus(UpdateModel::UpdateStatus::InstallFailed);
         return;
@@ -132,13 +112,20 @@ void UpdateWorker::doDistUpgrade(bool doBackup)
     }
 
     cleanLaStoreJob(m_distUpgradeJob);
+    cleanLaStoreJob(m_backupJob);
+    UpdateModel::instance()->setHasBackup(doBackup);
     QDBusPendingReply<QDBusObjectPath> reply = m_dbusProxy->DistUpgradePartly(UpdateModel::instance()->updateMode(), doBackup);
     QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(reply, this);
-    connect(watcher, &QDBusPendingCallWatcher::finished, this, [this, reply, watcher] {
+    connect(watcher, &QDBusPendingCallWatcher::finished, this, [this, reply, watcher, doBackup] {
         watcher->deleteLater();
         if (reply.isValid()) {
-            UpdateModel::instance()->setUpdateStatus(UpdateModel::UpdateStatus::Installing);
-            createDistUpgradeJob(reply.value().path());
+            if (doBackup) {
+                createBackupJob(reply.value().path());
+            } else {
+                UpdateModel::instance()->setUpdateStatus(UpdateModel::UpdateStatus::Installing);
+                createDistUpgradeJob(reply.value().path());
+            }
+            
         } else {
             const QString &errorMessage = watcher->error().message();
             qWarning() << "Do dist upgrade failed:" << watcher->error().message();
@@ -170,6 +157,9 @@ void UpdateWorker::onJobListChanged(const QList<QDBusObjectPath> &jobs)
         } else if (id == "check_system" && m_checkSystemJob == nullptr) {
             qInfo() << "Create check system job";
             createCheckSystemJob(jobPath);
+        } else if (id == "backup" && m_backupJob == nullptr) {
+            qInfo() << "Create backup job";
+            createBackupJob(jobPath);
         }
     }
 }
@@ -219,6 +209,26 @@ void UpdateWorker::createCheckSystemJob(const QString& jobPath)
     onCheckSystemStatusChanged(m_checkSystemJob->status());
 }
 
+void UpdateWorker::createBackupJob(const QString& jobPath)
+{
+    qCInfo(DDE_UPDATE_WORKER) << "Create backup upgrade job, path:" << jobPath;
+    if (m_backupJob || jobPath.isEmpty()) {
+        qCInfo(DDE_UPDATE_WORKER) << "Job is not null or job path is empty";
+        return;
+    }
+
+    m_backupJob = new UpdateJobDBusProxy(jobPath, this);
+    connect(m_backupJob, &UpdateJobDBusProxy::ProgressChanged, UpdateModel::instance(), &UpdateModel::setJobProgress);
+    connect(m_backupJob, &UpdateJobDBusProxy::StatusChanged, this, &UpdateWorker::onBackupStatusChanged);
+    connect(m_backupJob, &UpdateJobDBusProxy::DescriptionChanged, this, [this](const QString &description) {
+        if (m_backupJob->status() == "failed") {
+            UpdateModel::instance()->setLastErrorLog(description);
+        }
+    });
+    UpdateModel::instance()->setJobProgress(m_backupJob->progress());
+    onBackupStatusChanged(m_backupJob->status());
+}
+
 void UpdateWorker::onDistUpgradeStatusChanged(const QString &status)
 {
     // 无需处理ready状态
@@ -295,6 +305,30 @@ void UpdateWorker::onCheckSystemStatusChanged(const QString &status)
     }
 }
 
+void UpdateWorker::onBackupStatusChanged(const QString &value)
+{
+    qCInfo(DDE_UPDATE_WORKER) << "backup status changed: " << value;
+    if (value == "failed") {
+        const auto& description = m_backupJob->description();
+
+        auto error = analyzeJobErrorMessage(description);
+        if (error == UpdateModel::UpdateError::InstallNoSpace) {
+            UpdateModel::instance()->setUpdateError(UpdateModel::UpdateError::BackupNoSpace);
+        } else if (error == UpdateModel::UpdateError::UnKnown) {
+            UpdateModel::instance()->setUpdateError(UpdateModel::UpdateError::BackupFailedUnknownReason);
+        } else {
+            UpdateModel::instance()->setUpdateError(error);
+        }
+
+        UpdateModel::instance()->setLastErrorLog(description);
+        UpdateModel::instance()->setUpdateStatus(UpdateModel::UpdateStatus::BackupFailed);
+    } else if (value == "end") {
+        cleanLaStoreJob(m_backupJob);
+    } else if (value == "running") {
+        UpdateModel::instance()->setUpdateStatus(UpdateModel::UpdateStatus::BackingUp);
+    }
+}
+
 UpdateModel::UpdateError UpdateWorker::analyzeJobErrorMessage(QString jobDescription)
 {
     qInfo() << "Analyze job error message: " << jobDescription;
@@ -323,39 +357,20 @@ UpdateModel::UpdateError UpdateWorker::analyzeJobErrorMessage(QString jobDescrip
 
 void UpdateWorker::doDistUpgradeIfCanBackup()
 {
-#if 0 // TODO
+// TODO 进入更新的接口
     qInfo() << "Prepare to do backup";
-    QDBusPendingCall call = m_abRecoveryInter->CanBackup();
-    QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(call, this);
-    connect(watcher, &QDBusPendingCallWatcher::finished, this, [this, call] {
-        if (!call.isError()) {
-            QDBusReply<bool> reply = call.reply();
-            const bool value = reply.value();
-            if (value) {
-                m_abRecoveryInter->setSync(true);
-                const bool hasBackedUp = m_abRecoveryInter->hasBackedUp();
-                m_abRecoveryInter->setSync(false);
-                qInfo() << "Has backed up:" << hasBackedUp;
-                if (hasBackedUp) {
-                    UpdateModel::instance()->setUpdateStatus(UpdateModel::BackupSuccess);
-                } else {
-                    UpdateModel::instance()->setUpdateStatus(UpdateModel::BackingUp);
-                }
-                doDistUpgrade(true);
-            } else {
-                qWarning() << "Can not backup";
-                UpdateModel::instance()->setLastErrorLog(reply.error().message());
-                UpdateModel::instance()->setUpdateError(UpdateModel::CanNotBackup);
-                UpdateModel::instance()->setUpdateStatus(UpdateModel::BackupFailed);
-            }
-        } else {
-            qWarning() << "Call `CanBackup` failed";
-            UpdateModel::instance()->setLastErrorLog("Call `CanBackup` method in dbus interface - com.deepin.ABRecovery failed");
-            UpdateModel::instance()->setUpdateError(UpdateModel::UpdateInterfaceError);
-            UpdateModel::instance()->setUpdateStatus(UpdateModel::UpdateStatus::BackupFailed);
-        }
-    });
-#endif
+    // TODO: 暂未支持选择是否备份，之后会在社区版支持，现在默认备份
+    bool needBackup = true;
+    // TODO: 磐石暂未实现当前能否备份的接口，当前默认支持
+    bool canBackup = true;
+    if(canBackup) {
+        doDistUpgrade(needBackup);
+    } else {
+        qWarning() << "Can not backup";
+        UpdateModel::instance()->setLastErrorLog("");
+        UpdateModel::instance()->setUpdateError(UpdateModel::UpdateError::CanNotBackup);
+        UpdateModel::instance()->setUpdateStatus(UpdateModel::UpdateStatus::InstallFailed);
+    }
 }
 
 void UpdateWorker::doCheckSystem(int updateMode, UpdateModel::CheckSystemStage stage)
@@ -556,7 +571,7 @@ void UpdateWorker::checkStatusAfterSessionActive()
             return;
         }
     }
-    const int lastoreDaemonStatus = DConfigHelper::instance()->getConfig("org.deepin.lastore", "org.deepin.lastore", "","lastore-daemon-status", 0).toInt();
+    const int lastoreDaemonStatus = DConfigHelper::instance()->getConfig("org.deepin.dde.lastore", "org.deepin.dde.lastore", "","lastore-daemon-status", 0).toInt();
     qInfo() << "Lastore daemon status: " << lastoreDaemonStatus;
     static const int IS_UPDATE_READY = 1; // 第一位表示更新是否可用
     const bool isUpdateReady = lastoreDaemonStatus & IS_UPDATE_READY;
@@ -637,3 +652,46 @@ void UpdateWorker::forceReboot(bool reboot)
         }
     });
 }
+
+bool UpdateWorker::exportUpdateLog()
+{
+    const auto& [uid, name] = getCurrentUser();
+    if (uid == 0) {
+        qWarning() << "Current user's uid is invalid";
+        emit exportUpdateLogFinished(false);
+        return false;
+    }
+
+    QString homeDir = QString("/home/%1").arg(name);
+    QString desktopPath = QDir(homeDir).absoluteFilePath("Desktop");
+
+    if (desktopPath.isEmpty()) {
+        qWarning() << "Cannot get desktop path";
+        emit exportUpdateLogFinished(false);
+        return false;
+    }
+    
+    QDateTime currentTime = QDateTime::currentDateTime();
+    QString fileName = QString("%1_%2.txt").arg(tr("updatelog")).arg(currentTime.toString("yyyy_MM_dd_HH.mm.ss"));
+    QString exportTargetPath = QDir(desktopPath).filePath(fileName);
+
+    qInfo() << "Export update log to:" << exportTargetPath;
+
+    QDBusPendingCall call = m_dbusProxy->ExportUpdateDetails(exportTargetPath);
+    QDBusPendingCallWatcher* watcher = new QDBusPendingCallWatcher(call, this);
+    
+    connect(watcher, &QDBusPendingCallWatcher::finished, this, [this, watcher, exportTargetPath] {
+        QDBusPendingReply<void> reply = *watcher;
+        if (reply.isError()) {
+            qWarning() << "Export update details failed, error:" << reply.error().message();
+            emit exportUpdateLogFinished(false);
+        } else {
+            qInfo() << "Export update log successfully to:" << exportTargetPath;
+            emit exportUpdateLogFinished(true);
+        }
+
+        watcher->deleteLater();
+    });
+    
+    return true;
+}
